import Lib
main = configCheckTest "custom-b"
